@@ -4,7 +4,7 @@
 */
 
 #include	"auth.h"
-#include	"authstaticlist.h"
+#include	"courierauthstaticlist.h"
 #include	"courierauthsasl.h"
 #include	"authwait.h"
 #include	"courierauthdebug.h"
@@ -19,7 +19,6 @@
 #include	"numlib/numlib.h"
 #include	"authchangepwdir.h"
 
-static const char rcsid[]="$Id: authmoduser2.c,v 1.9 2004/11/17 01:16:00 mrsam Exp $";
 
 extern int authdaemondopasswd(char *, int);
 
@@ -60,7 +59,7 @@ int auth_passwd(const char *service,
 	if (authdaemondopasswd(buf, strlen(buf)))
 	{
 		free(buf);
-		sleep(5);
+		/*sleep(5);*/
 		return (-1);
 	}
 	free(buf);
