@@ -25,11 +25,10 @@
 #undef	TESTMODE
 #define	TESTMODE	1
 #endif
-#include	"../liblock/config.h"
-#include	"../liblock/liblock.h"
-#include	"../numlib/numlib.h"
+#include	"liblock/config.h"
+#include	"liblock/liblock.h"
+#include	"numlib/numlib.h"
 
-static const char rcsid[]="$Id: logger.c,v 1.11 2006/06/01 10:47:33 mrsam Exp $";
 
 static int do_logger(const char *name, int facility, FILE *f)
 {
